@@ -19,6 +19,7 @@ package main
 import (
 	"context"
 	"fmt"
+	"maps"
 	"os"
 	"sort"
 	"strings"
@@ -32,6 +33,7 @@ import (
 	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/engine"
 	"github.com/stefanprodan/timoni/internal/flags"
+	"github.com/stefanprodan/timoni/internal/runtime"
 )
 
 var bundleBuildCmd = &cobra.Command{
@@ -50,9 +52,11 @@ var bundleBuildCmd = &cobra.Command{
 }
 
 type bundleBuildFlags struct {
-	pkg   flags.Package
-	files []string
-	creds flags.Credentials
+	pkg            flags.Package
+	files          []string
+	creds          flags.Credentials
+	runtimeFromEnv bool
+	runtimeFiles   []string
 }
 
 var bundleBuildArgs bundleBuildFlags
@@ -61,6 +65,10 @@ func init() {
 	bundleBuildCmd.Flags().VarP(&bundleBuildArgs.pkg, bundleBuildArgs.pkg.Type(), bundleBuildArgs.pkg.Shorthand(), bundleBuildArgs.pkg.Description())
 	bundleBuildCmd.Flags().StringSliceVarP(&bundleBuildArgs.files, "file", "f", nil,
 		"The local path to bundle.cue files.")
+	bundleBuildCmd.Flags().BoolVar(&bundleBuildArgs.runtimeFromEnv, "runtime-from-env", false,
+		"Inject runtime values from the environment.")
+	bundleBuildCmd.Flags().StringSliceVarP(&bundleBuildArgs.runtimeFiles, "runtime", "r", nil,
+		"The local path to runtime.cue files.")
 	bundleBuildCmd.Flags().Var(&bundleBuildArgs.creds, bundleBuildArgs.creds.Type(), bundleBuildArgs.creds.Description())
 	bundleCmd.AddCommand(bundleBuildCmd)
 }
@@ -89,7 +97,36 @@ func runBundleBuildCmd(cmd *cobra.Command, _ []string) error {
 	ctx := cuecontext.New()
 	bm := engine.NewBundleBuilder(ctx, files)
 
-	if err := bm.InitWorkspace(tmpDir); err != nil {
+	runtimeValues := make(map[string]string)
+
+	if bundleBuildArgs.runtimeFromEnv {
+		maps.Copy(runtimeValues, engine.GetEnv())
+	}
+
+	if len(bundleBuildArgs.runtimeFiles) > 0 {
+		kctx, cancel := context.WithTimeout(cmd.Context(), rootArgs.timeout)
+		defer cancel()
+
+		rt, err := buildRuntime(bundleBuildArgs.runtimeFiles)
+		if err != nil {
+			return err
+		}
+
+		rm, err := runtime.NewResourceManager(kubeconfigArgs)
+		if err != nil {
+			return err
+		}
+
+		reader := runtime.NewResourceReader(rm)
+		rv, err := reader.Read(kctx, rt.Refs)
+		if err != nil {
+			return err
+		}
+
+		maps.Copy(runtimeValues, rv)
+	}
+
+	if err := bm.InitWorkspace(tmpDir, runtimeValues); err != nil {
 		return describeErr(tmpDir, "failed to parse bundle", err)
 	}
 
