@@ -35,6 +35,7 @@ import (
 	apiv1 "github.com/stefanprodan/timoni/api/v1alpha1"
 	"github.com/stefanprodan/timoni/internal/engine"
 	"github.com/stefanprodan/timoni/internal/flags"
+	"github.com/stefanprodan/timoni/internal/signutil"
 )
 
 var pushModCmd = &cobra.Command{
@@ -65,6 +66,11 @@ container registry using the version as the image tag.`,
 	--annotations='org.opencontainers.image.licenses=Apache-2.0' \
 	--annotations='org.opencontainers.image.documentation=https://app.org/docs' \
 	--annotations='org.opencontainers.image.description=A timoni.sh module for my app.'
+
+  # Push a module and sign it with Cosign Keyless (the cosign binary must be present in PATH)
+  timoni mod push ./path/to/module oci://ghcr.io/org/modules/app \
+	--version=1.0.0 \
+	--sign=cosign
 `,
 	RunE: pushModCmdRun,
 }
@@ -78,6 +84,8 @@ type pushModFlags struct {
 	ignorePaths []string
 	output      string
 	annotations []string
+	sign        string
+	cosignKey   string
 }
 
 var pushModArgs pushModFlags
@@ -93,6 +101,10 @@ func init() {
 		"Set custom OCI annotations in the format '<key>=<value>'.")
 	pushModCmd.Flags().StringVarP(&pushModArgs.output, "output", "o", "",
 		"The format in which the artifact digest should be printed, can be 'yaml' or 'json'.")
+	pushModCmd.Flags().StringVar(&pushModArgs.sign, "sign", "",
+		"Signs the module with the specified provider.")
+	pushModCmd.Flags().StringVar(&pushModArgs.cosignKey, "cosign-key", "",
+		"The Cosign private key for signing the module.")
 
 	modCmd.AddCommand(pushModCmd)
 }
@@ -194,6 +206,13 @@ func pushModCmdRun(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf("artifact tag parsing failed: %w", err)
 	}
 
+	if pushModArgs.sign != "" {
+		err = signutil.Sign(log, pushModArgs.sign, digestURL, pushModArgs.cosignKey)
+		if err != nil {
+			return err
+		}
+	}
+
 	info := struct {
 		URL        string `json:"url"`
 		Repository string `json:"repository"`
